@@ -15,12 +15,17 @@
 // Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
 #include <stdlib.h>
-#include <GL/glew.h>
 #include <AL/alc.h>
 #include <AL/al.h>
 #include <ode/ode.h>
+#include <XL/xl.h>
 #include <gtk/gtk.h>
 #include "mymachines.h"
+#include "mymachine.h"
+#include "mytrack.h"
+#include "mycheckpoints.h"
+#include "mygadget.h"
+#include "mybox.h"
 
 void
 on_game_new_activate(GtkAction *action, gpointer data)
@@ -159,7 +164,7 @@ on_machines_value_changed(GtkRange *range, gpointer data)
 
 	widget = GTK_WIDGET(gtk_builder_get_object(builder, "players"));
 	adjustment = gtk_range_get_adjustment(GTK_RANGE(widget));
-	gtk_range_set_range(GTK_RANGE(widget), adjustment->lower, MIN(5, gtk_range_get_value(range) + 1));
+	gtk_range_set_range(GTK_RANGE(widget), adjustment->lower, MIN(4, gtk_range_get_value(range)));
 	gtk_widget_queue_draw(widget);
 }
 
@@ -227,10 +232,10 @@ on_my_load(MyMachines *machines, MyMachinesLoadState state, gpointer data)
 		case MY_MACHINES_LOAD_BEGIN:
 			gtk_widget_show(widget);
 			break;
-		case MY_MACHINES_LOAD_TRACK:
+		case MY_MACHINES_LOAD_RACE:
 			widget = GTK_WIDGET(gtk_builder_get_object(builder, "statusbar"));
 			gtk_statusbar_pop(GTK_STATUSBAR(widget), 0);
-			gtk_statusbar_push(GTK_STATUSBAR(widget), 0, "Loading track");
+			gtk_statusbar_push(GTK_STATUSBAR(widget), 0, "Loading race");
 			break;
 		case MY_MACHINES_LOAD_ITEMS:
 			widget = GTK_WIDGET(gtk_builder_get_object(builder, "statusbar"));
@@ -258,7 +263,7 @@ on_my_load(MyMachines *machines, MyMachinesLoadState state, gpointer data)
 }
 
 void
-on_my_gadget_captured(MyMachines *machines, guint player, MyMachinesGadget gadget, gpointer data)
+on_my_gadget_captured(MyMachines *machines, guint player, unsigned int gadget, gpointer data)
 {
 	GtkBuilder *builder = GTK_BUILDER(data);
 	GtkWidget *widget;
@@ -270,13 +275,12 @@ on_my_gadget_captured(MyMachines *machines, guint player, MyMachinesGadget gadge
 	widget = GTK_WIDGET(gtk_builder_get_object(builder, "statusbar"));
 	gtk_statusbar_pop(GTK_STATUSBAR(widget), 0);
 	text = g_strdup_printf("%s player gets %s gadget", my_machines_get_player_color(machines, player), my_machines_get_gadget(machines, gadget));
-	text[0] = g_ascii_toupper(text[0]);
 	gtk_statusbar_push(GTK_STATUSBAR(widget), 0, text);
 	g_free(text);
 }
 
 void
-on_my_gadget_released(MyMachines *machines, guint player, MyMachinesGadget gadget, gpointer data)
+on_my_gadget_released(MyMachines *machines, guint player, unsigned int gadget, gpointer data)
 {
 	GtkBuilder *builder = GTK_BUILDER(data);
 	GtkWidget *widget;
@@ -288,7 +292,6 @@ on_my_gadget_released(MyMachines *machines, guint player, MyMachinesGadget gadge
 	widget = GTK_WIDGET(gtk_builder_get_object(builder, "statusbar"));
 	gtk_statusbar_pop(GTK_STATUSBAR(widget), 0);
 	text = g_strdup_printf("%s player looses %s gadget", my_machines_get_player_color(machines, player), my_machines_get_gadget(machines, gadget));
-	text[0] = g_ascii_toupper(text[0]);
 	gtk_statusbar_push(GTK_STATUSBAR(widget), 0, text);
 	g_free(text);
 }
@@ -306,7 +309,6 @@ on_my_win_point(MyMachines *machines, guint player, gpointer data)
 	widget = GTK_WIDGET(gtk_builder_get_object(builder, "statusbar"));
 	gtk_statusbar_pop(GTK_STATUSBAR(widget), 0);
 	text = g_strdup_printf("%s player wins point", my_machines_get_player_color(machines, player));
-	text[0] = g_ascii_toupper(text[0]);
 	gtk_statusbar_push(GTK_STATUSBAR(widget), 0, text);
 	g_free(text);
 }
@@ -324,7 +326,6 @@ on_my_loose_point(MyMachines *machines, guint player, gpointer data)
 	widget = GTK_WIDGET(gtk_builder_get_object(builder, "statusbar"));
 	gtk_statusbar_pop(GTK_STATUSBAR(widget), 0);
 	text = g_strdup_printf("%s player looses point", my_machines_get_player_color(machines, player));
-	text[0] = g_ascii_toupper(text[0]);
 	gtk_statusbar_push(GTK_STATUSBAR(widget), 0, text);
 	g_free(text);
 }
@@ -339,7 +340,6 @@ on_my_out_point(MyMachines *machines, guint player, gpointer data)
 	widget = GTK_WIDGET(gtk_builder_get_object(builder, "statusbar"));
 	gtk_statusbar_pop(GTK_STATUSBAR(widget), 0);
 	text = g_strdup_printf("%s player is out of point", my_machines_get_player_color(machines, player));
-	text[0] = g_ascii_toupper(text[0]);
 	gtk_statusbar_push(GTK_STATUSBAR(widget), 0, text);
 	g_free(text);
 }
@@ -354,7 +354,6 @@ on_my_win(MyMachines *machines, guint player, gpointer data)
 	widget = GTK_WIDGET(gtk_builder_get_object(builder, "statusbar"));
 	gtk_statusbar_pop(GTK_STATUSBAR(widget), 0);
 	text = g_strdup_printf("%s player wins", my_machines_get_player_color(machines, player));
-	text[0] = g_ascii_toupper(text[0]);
 	gtk_statusbar_push(GTK_STATUSBAR(widget), 0, text);
 	g_free(text);
 }
@@ -378,7 +377,6 @@ main(int argc, char **argv)
 	ALCdevice *device;
 	ALCcontext *acontext;
 
-	glewInit();
 	gtk_init(&argc, &argv);
 	device = alcOpenDevice(NULL);
 	if(device)
@@ -388,24 +386,33 @@ main(int argc, char **argv)
 		{
 			alcMakeContextCurrent(acontext);
 			dInitODE();
-				gtk_window_set_default_icon_from_file(DATADIR "/icons/" PACKAGE_ICON, NULL);
-				builder = gtk_builder_new();
-					gtk_builder_add_from_file(builder, PACKAGE_DATADIR "/ui/" PACKAGE_UI, NULL);
-					my_fix(builder);
-					gtk_builder_connect_signals(builder, builder);
-						window = GTK_WIDGET(gtk_builder_get_object(builder, "window"));
-						widget = GTK_WIDGET(gtk_builder_get_object(builder, "area"));
-						g_signal_connect(widget, "my-state-changed", G_CALLBACK(on_my_state_changed), builder);
-						g_signal_connect(widget, "my-load", G_CALLBACK(on_my_load), builder);
-						g_signal_connect(widget, "my-gadget-captured", G_CALLBACK(on_my_gadget_captured), builder);
-						g_signal_connect(widget, "my-gadget-released", G_CALLBACK(on_my_gadget_released), builder);
-						g_signal_connect(widget, "my-win-point", G_CALLBACK(on_my_win_point), builder);
-						g_signal_connect(widget, "my-loose-point", G_CALLBACK(on_my_loose_point), builder);
-						g_signal_connect(widget, "my-out-point", G_CALLBACK(on_my_out_point), builder);
-						g_signal_connect(widget, "my-win", G_CALLBACK(on_my_win), builder);
-						gtk_widget_show(window);
-							gtk_main();
-					g_object_unref(G_OBJECT(builder));
+
+			xlCreateContext();
+
+			myMachineCreateContext();
+			myTrackCreateContext();
+			myCheckPointsCreateContext();
+			myGadgetCreateContext();
+			myBoxCreateContext();
+
+			gtk_window_set_default_icon_from_file(DATADIR "/icons/" PACKAGE_ICON, NULL);
+			builder = gtk_builder_new();
+				gtk_builder_add_from_file(builder, PACKAGE_DATADIR "/ui/" PACKAGE_UI, NULL);
+				my_fix(builder);
+				gtk_builder_connect_signals(builder, builder);
+					window = GTK_WIDGET(gtk_builder_get_object(builder, "window"));
+					widget = GTK_WIDGET(gtk_builder_get_object(builder, "area"));
+					g_signal_connect(widget, "my-state-changed", G_CALLBACK(on_my_state_changed), builder);
+					g_signal_connect(widget, "my-load", G_CALLBACK(on_my_load), builder);
+					g_signal_connect(widget, "my-gadget-captured", G_CALLBACK(on_my_gadget_captured), builder);
+					g_signal_connect(widget, "my-gadget-released", G_CALLBACK(on_my_gadget_released), builder);
+					g_signal_connect(widget, "my-win-point", G_CALLBACK(on_my_win_point), builder);
+					g_signal_connect(widget, "my-loose-point", G_CALLBACK(on_my_loose_point), builder);
+					g_signal_connect(widget, "my-out-point", G_CALLBACK(on_my_out_point), builder);
+					g_signal_connect(widget, "my-win", G_CALLBACK(on_my_win), builder);
+					gtk_widget_show(window);
+						gtk_main();
+				g_object_unref(G_OBJECT(builder));
 			dCloseODE();
 			alcMakeContextCurrent(NULL);
 			alcDestroyContext(acontext);
